@@ -33,7 +33,7 @@ def _convert_version(tup):
 
 
 # <
-version_info = (0, 4, 2)
+version_info = (0, 5)
 __version__ = _convert_version(version_info)
 
 del _convert_version
@@ -360,6 +360,11 @@ class ProgramBase(object):
                                 sp.add_argument(*arg, **kw)
 
     def _parse_args(self, *args, **kw):
+        """
+        optional keyword arguments:
+          default_sub_parser='<subparsername>', allows empty subparser
+          help_all=True -> show help for all subcommands with --help-all
+        """
         tmp_args = args if args else sys.argv[1:]
         name = kw.pop('default_sub_parser', None)
         if name is not None and '--version' not in tmp_args:
