@@ -152,6 +152,19 @@ class ParseHelpOutput:
                 return True
         return False
 
+    def between_curly_braces(self, chunk, elems):
+        """check if elements are in comma splitted contents of  {}"""
+        for l in self._chunks[chunk]:
+            start_idx = l.find('{')
+            end_idx = l.find('}')
+            test_elems = l[start_idx + 1:end_idx-1].split(',')
+            for elem in elems:
+                if elem not in test_elems:
+                    break
+            else:
+                return True
+        return False
+
 
 @pytest.fixture(scope='class')
 def program():
@@ -166,7 +179,8 @@ class TestProgram:
         assert pho.start('positional arguments', 'hg')
         if sys.version_info[:2] == (2, 6):
             # 2.6 argparse scrambles order
-            assert pho.somewhere('usage', 'git,e,d,f')
+            x = 'a b c d git'.split()
+            assert pho.between_curly_braces('usage', x)
         else:
             assert pho.somewhere('usage', 'c,d,f,e')
         assert pho.start('optional arguments', '--verbose')
